==> chat-uikit-react-native-0.0.2.tgz: package/components/Message/Message.tsx <==
import React from 'react';
import {
  View,
  StyleSheet,
  TouchableOpacity,
} from 'react-native';

import type { IMessageModel } from '@tencentcloud/chat-uikit-engine';

import { Avatar } from '../Avatar';
import { MessageContent } from './MessageContent';
import { SendFail } from './SendFail';
import type { ICustomElementProps } from './CustomElement';

interface IMessageProps {
  message: IMessageModel;
  nextMessage: IMessageModel,
  CustomElement?: React.ComponentType<ICustomElementProps>,
}

export const Message = (props: IMessageProps) => {
  const {
    message,
    nextMessage,
    CustomElement,
  } = props;

  //  message from the same user and whitin 5 min needs to join.
  let isJoinedMessage = false;
  if (nextMessage) {
    isJoinedMessage = (message.from === nextMessage.from && nextMessage.time - message.time <= 300);
  }

  return (
   <>
    <View style={[
      styles.messageContainer,
      message.flow === 'in' ? styles.messageIn : styles.messageOut,
      isJoinedMessage && styles.messageContainerJoined,
    ]}>
      {message.flow === 'in' && !isJoinedMessage && (
        <Avatar size={32} uri={message.avatar} />
      )}
      <TouchableOpacity
        activeOpacity={1}
      >
        <MessageContent
          message={message}
          isJoinedMessage={isJoinedMessage}
          CustomElement={CustomElement}
        />
      </TouchableOpacity>
      <SendFail message={message} />
    </View>
   </>
  );
};

const styles = StyleSheet.create({
  messageContainer: {
    flexDirection: 'row',
    alignItems: 'flex-end',
    marginBottom: 16,
  },
  messageContainerJoined: {
    marginBottom: 2,
  },
  messageIn: {
    paddingRight: 35,
    marginRight: 20,
  },
  messageOut: {
    justifyContent: 'flex-end',
    paddingLeft: 92,
  },
});

==> chat-uikit-react-native-0.0.3.tgz: package/components/Message/Message.tsx <==
import React from 'react';
import {
  View,
  StyleSheet,
  TouchableOpacity,
} from 'react-native';

import type { IMessageModel } from '@tencentcloud/chat-uikit-engine';

import { Avatar } from '../Avatar';
import { MessageContent } from './MessageContent';
import { SendFail } from './SendFail';
import type { ICustomElementProps } from './CustomElement';

interface IMessageProps {
  message: IMessageModel;
  nextMessage: IMessageModel;
  CustomElement?: React.ComponentType<ICustomElementProps>;
}

export const Message = (props: IMessageProps) => {
  const {
    message,
    nextMessage,
    CustomElement,
  } = props;

  //  message from the same user and whitin 5 min needs to join.
  let isJoinedMessage = false;
  if (nextMessage) {
    isJoinedMessage = (message.from === nextMessage.from && nextMessage.time - message.time <= 300);
  }

  return (
    <>
      <View style={[
        styles.messageContainer,
        message.flow === 'in' ? styles.messageIn : styles.messageOut,
        isJoinedMessage && styles.messageContainerJoined,
      ]}
      >
        {message.flow === 'in' && !isJoinedMessage && (
          <Avatar size={32} uri={message.avatar} />
        )}
        <TouchableOpacity
          activeOpacity={1}
        >
          <MessageContent
            message={message}
            isJoinedMessage={isJoinedMessage}
            CustomElement={CustomElement}
          />
        </TouchableOpacity>
        <SendFail message={message} />
      </View>
    </>
  );
};

const styles = StyleSheet.create({
  messageContainer: {
    flexDirection: 'row',
    alignItems: 'flex-end',
    marginBottom: 16,
  },
  messageContainerJoined: {
    marginBottom: 2,
  },
  messageIn: {
    paddingRight: 35,
    marginRight: 20,
  },
  messageOut: {
    justifyContent: 'flex-end',
    paddingLeft: 92,
  },
});
